@@ -1,5 +1,6 @@
 from dataclasses import dataclass, field
-from typing import List,Optional
+from typing import Optional
+from sdk.models import shared
 from sdk.models import shared
 
 
@@ -7,6 +8,6 @@ from sdk.models import shared
 class GetValidEmbedAccessTokensResponse:
     content_type: str = field()
     status_code: int = field()
-    embed_tokens: Optional[List[shared.EmbedToken]] = field(default=None)
+    embed_tokens: Optional[list[shared.EmbedToken]] = field(default=None)
     error: Optional[shared.Error] = field(default=None)
     
